@@ -175,10 +175,11 @@ AttributeTableEntry attributeTable[] = {
     { "FrameLockTiming",       NV_CTRL_FRAMELOCK_TIMING,            N|F|G,   "This is 1 when the GPU is both receiving and locked to an input timing signal. Timing information may come from the following places: Another frame lock device that is set to master, the house sync signal, or the GPU's internal timing from a display device." },
     { "FramelockUseHouseSync", NV_CTRL_USE_HOUSE_SYNC,              N|F|G,   "When 1, the server (master) frame lock device will propagate the incoming house sync signal as the outgoing frame lock sync signal.  If the frame lock device cannot detect a frame lock sync signal, it will default to using the internal timings from the GPU connected to the primary connector." },
     { "FrameLockSlaves",       NV_CTRL_FRAMELOCK_SLAVES,            N|F|G|D, "Get/set whether the display device(s) given should listen or ignore the master's sync signal." },
-    { "FrameLockMasterable",   NV_CTRL_FRAMELOCK_MASTERABLE,        N|F|G,   "Returns whether the display device(s) can be set as the master of the frame lock group.  Returns 1 if the GPU driving the display device is connected to the \"primary\" connector on the frame lock board." },
+    { "FrameLockMasterable",   NV_CTRL_FRAMELOCK_MASTERABLE,        N|F|G|D, "Returns whether the display device(s) can be set as the master of the frame lock group.  Returns a bitmask indicating which of the given display devices can be set as a frame lock master." },
     { "FrameLockSlaveable",    NV_CTRL_FRAMELOCK_SLAVEABLE,         N|F|G|D, "Returns whether the display device(s) can be set as slave(s) of the frame lock group." },
     { "FrameLockFPGARevision", NV_CTRL_FRAMELOCK_FPGA_REVISION,     N|F|G,   "Returns the FPGA revision of the Frame Lock device." },
     { "FrameLockSyncRate4",    NV_CTRL_FRAMELOCK_SYNC_RATE_4,       N|F|G,   "Returns the refresh rate that the frame lock board is sending to the GPU in 1/10000 Hz (i.e. to get the refresh rate in Hz, divide the returned value by 10000.)" },
+    { "FrameLockSyncDelayResolution", NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION, N|F|G, "Returns the number of nanoseconds that one unit of FrameLockSyncDelay corresponds to." },
 
     /* GVO */
     { "GvoSupported",                    NV_CTRL_GVO_SUPPORTED,                        I|N,   "Returns whether this X screen supports GVO; if this screen does not support GVO output, then all other GVO attributes are unavailable." },
@@ -289,7 +290,7 @@ AttributeTableEntry attributeTable[] = {
  * about.
  */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_IMAGE_SHARPENING_DEFAULT
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION
 #warning "Have you forgotten to add a new integer attribute to attributeTable?"
 #endif
 
@@ -307,28 +308,32 @@ TargetTypeEntry targetTypeTable[] = {
       X_SCREEN_TARGET,               /* target_index */
       NV_CTRL_TARGET_TYPE_X_SCREEN,  /* nvctrl */
       ATTRIBUTE_TYPE_X_SCREEN,       /* permission_bit */
-      NV_TRUE },                     /* uses_display_devices */
+      NV_TRUE,                       /* uses_display_devices */
+      1, 6 },                        /* required major,minor protocol rev */
     
     { "GPU",                         /* name */
       "gpu",                         /* parsed_name */
       GPU_TARGET,                    /* target_index */
       NV_CTRL_TARGET_TYPE_GPU,       /* nvctrl */
       ATTRIBUTE_TYPE_GPU,            /* permission_bit */
-      NV_TRUE },                     /* uses_display_devices */
+      NV_TRUE,                       /* uses_display_devices */
+      1, 10 },                       /* required major,minor protocol rev */
     
     { "Frame Lock Device",           /* name */
       "framelock",                   /* parsed_name */
       FRAMELOCK_TARGET,              /* target_index */
       NV_CTRL_TARGET_TYPE_FRAMELOCK, /* nvctrl */
       ATTRIBUTE_TYPE_FRAMELOCK,      /* permission_bit */
-      NV_FALSE },                    /* uses_display_devices */
+      NV_FALSE,                      /* uses_display_devices */
+      1, 10 },                       /* required major,minor protocol rev */
 
     { "VCS",                         /* name */
       "vcs",                         /* parsed_name */
       VCS_TARGET,                    /* target_index */
       NV_CTRL_TARGET_TYPE_VCSC,      /* nvctrl */
       ATTRIBUTE_TYPE_VCSC,           /* permission_bit */
-      NV_FALSE },                    /* uses_display_devices */
+      NV_FALSE,                      /* uses_display_devices */
+      1, 12 },                       /* required major,minor protocol rev */
 
     { NULL, NULL, 0, 0, 0 },
 };
@@ -1091,12 +1096,16 @@ void nv_parsed_attribute_clean(ParsedAttribute *p)
  * corresponds to the attribute constant.
  */
 
-char *nv_get_attribute_name(const int attr)
+const char *nv_get_attribute_name(const int attr, const int flagsMask,
+                                  const int flags)
 {
     int i;
 
     for (i = 0; attributeTable[i].name; i++) {
-        if (attributeTable[i].attr == attr) return attributeTable[i].name;
+        if (attributeTable[i].attr == attr &&
+            (attributeTable[i].flags & flagsMask) == (flags & flagsMask)) {
+            return attributeTable[i].name;
+        }
     }
 
     return NULL;
